% Adapted from code by Jean Derks,  
% Dept. of Knowledge Engineering, Maastricht University.

W=w(1); for i=2:length(w), W=[W w(i) W+w(i)]; end
v=(W>=q);
N=length(v);n=length(w);

x=w/sum(w);

X=x(1); for i=2:length(x), X=[X x(i) X+x(i)]; end
[th,U]=sort(v-X,'descend' );
e=th(1)-100*eps;
for m=1:N, if th(m)<e; break; end, end
A=zeros(n,m-1);
for j=1:m-1, S=U(j); for i=1:n, A(i,j)=bitget(S,i); end, end

% Matrix A constructed in this way has as many rows (n) as players and as 
% many columns (m-1) as coalitions are in W*, the set of winning coalitions 
% of minimum weight. An entry in the matrix is 1 if the player in that row 
% belongs to the coalition in that column, and 0 otherwise.

l = linprog(ones(m-1,1),(-1)*eye(m-1,m-1),zeros(m-1,1),A,ones(n,1));

% l is a vector whose entries are what in the paper is denoted by 
% (lambda_S) with S in W*
% The objective function in the linear program above is arbitrary, since 
% what matters is whether the program is feasible. 
% The feasibility of the program has two elements: the nonnegativity 
% constraint on each entry in l, written in matrix form as
% (-1)*eye(m-1,m-1)*l<=zeros(m-1,1), and the requirement that, for any 
% player i, the sum of lambda_S is equal to 1, written in matrix form 
% as A*l = ones(n,1). 


% MATLAB reports a solution for l, even if the program is unfeasible.
% The next line checks A*l, which will be equal to ones(n,1) if and only if 
% the returned value of l is a feasible solution 

A*l;

if abs(sum(A*l-ones(n,1)))< 1.0e-07,disp('Condition satisfied'); 
else disp('Condition not satisfied'); end







